confirmSignIn static method
AuthProvider for performing Authentication.confirmSignIn.
Authentication.confirmSignInを実行するためのAuthProvider。
Pass url the link that was included in the email.
urlにメールに記載していたリンクを渡します。
An AuthQuery for link authentication via email.
An email with a link is sent at signIn, and the link is confirmed at confirmSignIn to log in.
No password will be required.
After logging in, you will be able to change your e-mail address.
Eメールでリンク認証を行うためのAuthQuery。
signIn時にリンク付きのメールを送信し、confirmSignInでリンクを確定してログインを行ないます。
パスワードが必要なくなります。
ログイン後、メールアドレスの変更が可能になります。
Implementation
static EmailLinkConfirmSignInAuthProvider confirmSignIn({
required String url,
}) {
return EmailLinkConfirmSignInAuthProvider(
url: url,
);
}