FormMapDropdownField<TValue> class

Drop down form to select from there with Map as an option.

A form field that allows you to select Key-Value pair Map format data from a dropdown menu. Common design can be applied with FormStyle, and selection state can be managed using FormController.

Key-ValueペアのMap形式のデータをドロップダウンメニューで選択できるフォームフィールド。 FormStyleで共通したデザインを適用可能。またFormControllerを利用することで選択状態を管理できます。

Basic Usage Example 基本的な使用例

final countries = <String, String>{
  "ja": "日本語",
  "en": "English",
  "es": "Español",
  "fr": "Français",
};

FormMapDropdownField(
  form: formController,
  initialValue: formController.value.selectedLanguage,
  onSaved: (value) => formController.value.copyWith(selectedLanguage: value),
  picker: FormMapDropdownFieldPicker(
    values: countries,
  ),
);

Usage Example with Validation バリデーション付きの使用例

FormMapDropdownField(
  form: formController,
  initialValue: formController.value.selectedLanguage,
  onSaved: (value) => formController.value.copyWith(selectedLanguage: value),
  validator: (value) {
    if (value == null) {
      return "地域を選択してください";
    }
    return null;
  },
  picker: FormMapDropdownFieldPicker(
    values: countries,
  ),
);
Inheritance

Constructors

FormMapDropdownField({required FormMapDropdownFieldPicker picker, FormController<TValue>? form, Key? key, FormAffixStyle? prefix, FormAffixStyle? suffix, String? hintText, String? labelText, String? emptyErrorText, FormStyle? style, void onChanged(String? value)?, FocusNode? focusNode, bool keepAlive = true, Widget? icon, bool expanded = false, TValue onSaved(String value)?, String validator(String? value)?, String? initialValue, bool enabled = true})
Drop down form to select from there with Map as an option.

Properties

autovalidateMode AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
builder FormFieldBuilder<String>
Function that returns the widget representing this form field.
finalinherited
emptyErrorText String?
Error text. Only displayed if no characters are entered.
final
enabled bool
Whether the form is able to receive user input.
finalinherited
errorBuilder FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
expanded bool
Extend the form.
final
focusNode FocusNode?
Specifies the focus node.
final
forceErrorText String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
form FormController<TValue>?
Context for forms.
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
Hint to be displayed on the form. Displayed when no text is entered.
final
icon Widget?
Specify the icon displayed on the right side of the drop-down form.
final
initialValue String?
An optional value to initialize the form field to, or null otherwise.
finalinherited
keepAlive bool
If placed in a list, whether or not it should not be discarded on scrolling.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String?
Label text for forms.
final
onChanged → void Function(String? value)?
Callback to be executed each time the value is changed.
final
onReset VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → void Function(String? value)?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
picker FormMapDropdownFieldPicker
Picker object for selecting from Map.
final
prefix FormAffixStyle?
A widget that is placed in front of the form.
final
restorationId String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style FormStyle?
Form Style.
final
suffix FormAffixStyle?
A widget that is placed after the form.
final
validator String? Function(String? value)?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() FormFieldState<String>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited