FormMapDropdownFieldPicker class

Class that defines the picker style for selection from Map.

Pass Map<String, String> to values. Key in Map is the ID for selection and Value is the display label for selection.

Mapから選択するためのピッカースタイルを定義するクラス。

Map<String, String>valuesに渡します。 MapのKeyが選択用のID、Valueが選択用の表示ラベルになります。

Constructors

FormMapDropdownFieldPicker({required Map<String, String> values, String labelBuilder(String? value)?})
Class that defines the picker style for selection from Map.

Properties

hashCode int
The hash code for this object.
no setterinherited
labelBuilder String Function(String? value)?
Label builder to create text to display choices.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, String>
Data for options.
final

Methods

build(BuildContext context) List<Widget>
Build the picker.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited