addRepaintBoundaries property
Set to true to provide a redraw area for the list (the part that is displayed on the screen).
リストの再描画領域(画面に表示される部分)を設ける場合はtrueに設定します。
Implementation
final bool addRepaintBoundaries;
Set to true to provide a redraw area for the list (the part that is displayed on the screen).
リストの再描画領域(画面に表示される部分)を設ける場合はtrueに設定します。
final bool addRepaintBoundaries;