LoadableControllerMixin<T> mixin

Provides the ability to load data into the controller.

Describe the data loading process in loadRequest.

Load data by calling load. Reload data by calling reload.

コントローラーにデータをロードする機能を提供します。

loadRequestにデータのロード処理を記述します。

loadを呼び出すことでデータをロードします。reloadでデータを再ロードします。

Superclass constraints
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
loaded bool
Return true if data is loaded.
no setter
loading Future<void>?
Returns Future if loading is being performed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
The current value of the object.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
load() Future<void>
Execute the process of loadRequest and load data.
loadRequest() Future<T?>
Describe the process for loading data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
reload() Future<void>
Execute the process of loadRequest and load data.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited