ModelAdapterDocumentQuery class

Query class to be passed when executing each function of ModelAdapter.

Use this when executing functions for documents. Use ModelAdapterCollectionQuery when performing collection queries.

ModelAdapterの各機能を実行する際に渡すクエリークラス。

ドキュメント用の機能を実行する際に利用します。コレクションのクエリを実行する際はModelAdapterCollectionQueryをご利用ください。

Annotations

Constructors

ModelAdapterDocumentQuery({required DocumentModelQuery query, void callback(ModelUpdateNotification update)?, Object? origin, bool listen = true, Map<String, String> headers = const {}, String? method, bool reload = false, bool reference = false, bool asyncOnSave = false, int retryCount = 0})
Query class to be passed when executing each function of ModelAdapter.
const
ModelAdapterDocumentQuery.fromJson(Map<String, Object?> json)
Create a ModelAdapterDocumentQuery from a Map.
factory

Properties

asyncOnSave bool
Set to true to save asynchronously.
final
callback → void Function(ModelUpdateNotification update)?
A callback that is notified when changes are made to the relevant document.
final
hashCode int
The hash code for this object.
no setteroverride
headers Map<String, String>
Headers for sending a request.
final
listen bool
Set to true to monitor query changes.
final
method String?
Method for sending a request.
final
origin Object?
The original document object from which to perform the query.
final
query DocumentModelQuery
Document query.
final
reference bool
Returns true if the document indicates a reference from another.
final
reload bool
Set to true to force reload.
final
retryCount int
Retry count.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DocumentModelQuery? query, Map<String, String>? headers, String? method, bool? reload, bool? reference, bool? asyncOnSave, int? retryCount}) ModelAdapterDocumentQuery
Change headers or method, reload, reference, asyncOnSave, and query and copy.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert ModelAdapterDocumentQuery to Map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override