ModelFieldValueAsMapMixin<T> mixin

Mix-in to allow Json serialization and deserialization of ModelFieldValue.

It is treated as Map, but updating the value is not supported. UnsupportedError] is printed when attempting to update the value.

ModelFieldValueをJsonシリアライズ・デシリアライズできるようにするためのミックスイン。

Mapとして扱われますが、値の更新はサポートされていません。 値を更新しようとするとUnsupportedErrorが出力されます。

Implemented types
Available extensions

Properties

entries Iterable<MapEntry<String, Object?>>
The map entries of this Map.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setteroverride
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setteroverride
keys Iterable<String>
The keys of this Map.
no setteroverride
length int
The number of key/value pairs in the map.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
Actual value.
no setterinherited
values Iterable<Object?>
The values of this Map.
no setteroverride

Methods

addAll(Map<String, Object?> other) → void
Adds all key/value pairs of other to this map.
override
addEntries(Iterable<MapEntry<String, Object?>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
override
cast<RK, RV>() Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
override
clear() → void
Removes all entries from the map.
override
containsKey(Object? key) bool
Whether this map contains the given key.
override
containsValue(Object? value) bool
Whether this map contains the given value.
override
forEach(void action(String key, Object? value)) → void
Applies action to each key/value pair of the map.
override
getAsModelCounter(String key, [int defaultValue = 0]) ModelCounter

Available on DynamicMap, provided by the DynamicMapModelFieldValueExtensions extension

Retrieves the element of key of type ModelCounter from Map.
getAsModelDate(String key, [DateTime? defaultValue]) ModelDate

Available on DynamicMap, provided by the DynamicMapModelFieldValueExtensions extension

Retrieves the element of key of type ModelDate from Map.
getAsModelRef<T>(String key, String defaultPath) ModelRefBase<T>

Available on DynamicMap, provided by the DynamicMapModelFieldValueExtensions extension

Retrieves the element of key of type ModelRefBase from Map.
getAsModelTimestamp(String key, [DateTime? defaultValue]) ModelTimestamp

Available on DynamicMap, provided by the DynamicMapModelFieldValueExtensions extension

Retrieves the element of key of type ModelTimestamp from Map.
map<K2, V2>(MapEntry<K2, V2> transform(String key, Object? value)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, Object? ifAbsent()) Object?
Look up the value of key, or add a new entry if it isn't there.
override
remove(Object? key) Object?
Removes key and its associated value, if present, from the map.
override
removeWhere(bool test(String key, Object? value)) → void
Removes all entries of this map that satisfy the given test.
override
toEntireJson() DynamicMap

Available on DynamicMap, provided by the DynamicMapModelExtensions extension

Converts DynamicMap to Json considering ModelFieldValue.
toJson() DynamicMap
Methods for Json serialization.
inherited
toJsonString() String

Available on DynamicMap, provided by the JsonDynamicMapExtensions extension

Convert the contents of DynamicMap to a Json String.
toString() String
A string representation of this object.
override
toTreeMap([String keyBuilder(String key)?]) Map<String, dynamic>

Available on Map<String, dynamic>, provided by the DynamicMapExtensions extension

Converts a DynamicMap with a key of String in the path structure to a DynamicMap in the tree structure.
update(String key, Object? update(Object? key), {Object? ifAbsent()?}) Object?
Updates the value for the provided key.
override
updateAll(Object? update(String key, Object? value)) → void
Updates all values.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) Object?
The value for the given key, or null if key is not in the map.
override
operator []=(String key, Object? value) → void
Associates the key with the given value.
override