ModelTimestampRange class

Define the field as a range of timestamps.

The base value is given as value.

フィールドをタイムスタンプの範囲として定義します。

ベースの値をvalueとして与えます。

Inheritance
Implemented types
Annotations

Constructors

ModelTimestampRange(DateTimeRange<DateTime> value)
Define the field as a range of timestamps.
const
factory
ModelTimestampRange.fromDateTime({required DateTime start, required DateTime end})
Define the field as a range of timestamps.
const
factory
ModelTimestampRange.fromJson(DynamicMap json)
Convert from json map to ModelTimestamp.
factory
ModelTimestampRange.fromModelTimestamp({required ModelTimestamp start, required ModelTimestamp end})
Define the field as a range of timestamps.
const
factory
ModelTimestampRange.fromServer(DateTimeRange<DateTime> value)
Used to disguise the retrieval of data from the server.
const
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DateTimeRange<DateTime>
Actual value.
no setteroverride

Methods

compareTo(ModelTimestampRange other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() DynamicMap
Methods for Json serialization.
override
toModelDateRange() ModelDateRange
Convert to ModelDateRange.
toModelTimeRange() ModelTimeRange
Convert to ModelTimeRange.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

kEndTimeKey → const String
Key to save end time.
kSourceKey → const String
Key to store the data source.
kStartTimeKey → const String
Key to save start time.
typeString → const String
Type key.