RuntimeVectorConverter class

A converter for easy, runtime vector conversion.

It generates vectors using Bigram hash values and sorts them by proximity based on cosine similarity.

ランタイム上で簡易的にベクトル変換を行うコンバーター。

Bigramのハッシュ値を用いてベクトルを生成し、コサイン類似度に基づいて近い順に並び替えを行います。

Inheritance

Constructors

RuntimeVectorConverter({int dimensions = 10000000})
A converter for easy, runtime vector conversion.
const

Properties

dimensions int
Vector dimension.
final
distanceFieldKey String
Field key for distance.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeType VectorValueStoreType
The vector storage type.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seekIndex(List<MapEntry<String, DynamicMap>> sorted, DynamicMap data, String key, String searchText) FutureOr<int?>
Finds the index of the data closest to the specified vector.
override
sortByNearest(List<MapEntry<String, DynamicMap>> values, String key, String searchText) Future<List<MapEntry<String, DynamicMap>>>
Sorts the data by proximity to the specified vector.
override
toString() String
A string representation of this object.
inherited
toVector(String value) List<double>
Converts a string to a vector.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited