build abstract method
Build the internal widget.
The context used during the build is passed as is.
Also, WidgetRef is passed to ref to update the state.
内部のウィジェットをビルドします。
ビルド中に使用されるcontextがそのまま渡されます。
また、refに状態を更新するためのWidgetRefが渡されます。
Implementation
Widget build(BuildContext context, WidgetRef ref);