StorageQuery constructor

const StorageQuery(
  1. String relativeRemotePathOrId, {
  2. StorageAdapter? adapter,
  3. String? mimeType,
})

Query to specify the path of storage on the remote side.

Specify the relative path on the remote storage side in relativeRemotePathOrId.

If you want to specify StorageAdapter directly, pass it to adapter.

You can specify the MIME type for uploading by specifying mimeType.

リモート側のストレージのパスを指定するためのクエリ。

relativeRemotePathOrIdでリモートストレージ側の相対パスを指定します。

StorageAdapterを直接指定したい場合、adapterに渡してください。

mimeTypeを指定することでアップロード時のMIMEタイプを指定することができます。

Implementation

const StorageQuery(
  this.relativeRemotePathOrId, {
  StorageAdapter? adapter,
  this.mimeType,
}) : _adapter = adapter;