ModelRestApiBuilder class
Builder for creating model adapters using REST APIs.
REST APIを利用したモデルアダプターを作成するためのビルダー。
Constructors
- ModelRestApiBuilder({String? description, CollectionModelRestApiBuilder? collection, DocumentModelRestApiBuilder? document})
-
Builder for creating model adapters using REST APIs.
const
Properties
- collection → CollectionModelRestApiBuilder?
-
Builder for creating collection model adapters using REST APIs.
final
- description → String?
-
The description of the model adapter.
final
- document → DocumentModelRestApiBuilder?
-
Builder for creating document model adapters using REST APIs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited