ShimmerBox class
A container widget that displays a shimmer loading effect.
This widget creates a shimmer effect placeholder that can be used during loading states. Perfect for skeleton screens, loading placeholders, and content loading indicators.
Features:
- Customizable shimmer animation colors
- Adjustable width and height
- Configurable border radius
- Rectangle or circle shapes
- Theme-based default colors
- Optional child widget
- Enable/disable shimmer effect
Example:
ShimmerBox(
width: 200,
height: 20,
borderRadius: BorderRadius.circular(4),
baseColor: Colors.grey[300],
highlightColor: Colors.grey[100],
)
シマーローディングエフェクトを表示するコンテナウィジェット。
このウィジェットはローディング状態中に使用できるシマーエフェクトの プレースホルダーを作成します。スケルトンスクリーン、ローディングプレースホルダー、 コンテンツローディングインジケータに最適です。
特徴:
- カスタマイズ可能なシマーアニメーションカラー
- 調整可能な幅と高さ
- 設定可能なボーダー半径
- 矩形または円形の形状
- テーマベースのデフォルトカラー
- オプションの子ウィジェット
- シマーエフェクトの有効/無効化
例:
ShimmerBox(
width: 200,
height: 20,
borderRadius: BorderRadius.circular(4),
baseColor: Colors.grey[300],
highlightColor: Colors.grey[100],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ShimmerBox
Constructors
- ShimmerBox({Key? key, BorderRadiusGeometry? borderRadius, Color? baseColor, Color? highlightColor, double width = double.infinity, double? height, EdgeInsetsGeometry padding = const EdgeInsets.all(0), BoxShape shape = BoxShape.rectangle, Widget? child, bool enabled = true})
-
A container widget that displays a shimmer loading effect.
const
Properties
- baseColor → Color?
-
Base color for shimmer effects.
final
- borderRadius → BorderRadiusGeometry?
-
Rounded corners of containers.
final
- child → Widget?
-
Widget for the container inside.
final
- enabled → bool
-
Whether to display the shimmer effect.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Container height.
final
- highlightColor → Color?
-
Highlight color when using shimmer effect.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry
-
Padding around shimmer effects.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → BoxShape
-
Form of shimmer effect.
final
- width → double
-
Container width.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited